@@ -1,5 +1,7 @@
 #!/usr/bin/python3
 
+import argparse
+
 # This file provides the necessary data and functions to deal with the
 # Coq-related packages in Debian ; it's the basic foundation to be
 # used in various tools
@@ -246,4 +248,13 @@ def run_checks():
     print('done.')
 
 if __name__ == "__main__":
-    run_checks()
+    parser = argparse.ArgumentParser(description='Basic functions')
+    parser.add_argument('-rc', '--run-checks', action='store_true',
+                        help='run basic checks on the package list')
+    parser.add_argument('-m', '--minimal', action='store_true',
+                        help='list the leaf packages for the Coq ecosystem in Debian')
+    args = parser.parse_args()
+    if args.run_checks:
+        run_checks()
+    if args.minimal:
+        print(minimal_to_install_all())
